==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONASPECTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INSPECTIONASPECTPOINTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONASPECTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONPOINTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONASPECTPOINTID_Type", propOrder = {
    "inspectionpointid",
    "aspectid"
})
public class INSPECTIONASPECTPOINTID_Type {

    @XmlElement(name = "INSPECTIONPOINTID", required = true)
    protected INSPECTIONPOINTID_Type inspectionpointid;
    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;

    /**
     * Obtient la valeur de la propriété inspectionpointid.
     * 
     * @return
     *     possible object is
     *     {@link INSPECTIONPOINTID_Type }
     *     
     */
    public INSPECTIONPOINTID_Type getINSPECTIONPOINTID() {
        return inspectionpointid;
    }

    /**
     * Définit la valeur de la propriété inspectionpointid.
     * 
     * @param value
     *     allowed object is
     *     {@link INSPECTIONPOINTID_Type }
     *     
     */
    public void setINSPECTIONPOINTID(INSPECTIONPOINTID_Type value) {
        this.inspectionpointid = value;
    }

    /**
     * Obtient la valeur de la propriété aspectid.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Définit la valeur de la propriété aspectid.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONASPECTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INSPECTIONASPECTPOINTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONASPECTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONPOINTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONASPECTPOINTID_Type", propOrder = {
    "inspectionpointid",
    "aspectid"
})
public class INSPECTIONASPECTPOINTID_Type {

    @XmlElement(name = "INSPECTIONPOINTID", required = true)
    protected INSPECTIONPOINTID_Type inspectionpointid;
    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;

    /**
     * Gets the value of the inspectionpointid property.
     * 
     * @return
     *     possible object is
     *     {@link INSPECTIONPOINTID_Type }
     *     
     */
    public INSPECTIONPOINTID_Type getINSPECTIONPOINTID() {
        return inspectionpointid;
    }

    /**
     * Sets the value of the inspectionpointid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INSPECTIONPOINTID_Type }
     *     
     */
    public void setINSPECTIONPOINTID(INSPECTIONPOINTID_Type value) {
        this.inspectionpointid = value;
    }

    /**
     * Gets the value of the aspectid property.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Sets the value of the aspectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

}
